@@ -2,9 +2,9 @@
 # Mail::SPF::Base
 # Base class for Mail::SPF classes.
 #
-# (C) 2005-2006 Julian Mehnle <julian@mehnle.net>
+# (C) 2005-2012 Julian Mehnle <julian@mehnle.net>
 #     2005      Shevek <cpan@anarres.org>
-# $Id: Base.pm 14 2006-11-04 15:30:34Z Julian Mehnle $
+# $Id: Base.pm 57 2012-01-30 08:15:31Z julian $
 #
 ##############################################################################
 
@@ -29,7 +29,7 @@ use constant FALSE  => not TRUE;
 =head1 SYNOPSIS
 
     use base 'Mail::SPF::Base';
-    
+
     sub new {
         my ($class, @options) = @_;
         my $self = $class->SUPER::new(@options);
@@ -112,7 +112,7 @@ sub make_accessor {
         $accessor = sub {
             local *__ANON__ = $accessor_name;
             my ($self, @value) = @_;
-            throw Mail::SPF::EInstanceMethod() if not ref($self);
+            throw Mail::SPF::EInstanceMethod if not ref($self);
             throw Mail::SPF::EReadOnlyValue("$accessor_name is read-only") if @value;
             return $self->{$name};
         };
@@ -121,7 +121,7 @@ sub make_accessor {
         $accessor = sub {
             local *__ANON__ = $accessor_name;
             my ($self, @value) = @_;
-            throw Mail::SPF::EInstanceMethod() if not ref($self);
+            throw Mail::SPF::EInstanceMethod if not ref($self);
             $self->{$name} = $value[0] if @value;
             return $self->{$name};
         };
