@@ -2,9 +2,9 @@
 # Mail::SPF::Mod::Exp
 # SPF record "exp" modifier class.
 #
-# (C) 2005-2006 Julian Mehnle <julian@mehnle.net>
+# (C) 2005-2012 Julian Mehnle <julian@mehnle.net>
 #     2005      Shevek <cpan@anarres.org>
-# $Id: Exp.pm 22 2006-11-15 03:31:28Z Julian Mehnle $
+# $Id: Exp.pm 57 2012-01-30 08:15:31Z julian $
 #
 ##############################################################################
 
@@ -32,6 +32,8 @@ use constant FALSE  => not TRUE;
 use constant name           => 'exp';
 use constant name_pattern   => qr/${\name}/i;
 
+use constant precedence     => 0.2;
+
 =head1 DESCRIPTION
 
 An object of class B<Mail::SPF::Mod::Exp> represents an SPF record modifier of
@@ -58,10 +60,11 @@ See L<Mail::SPF::Mod/new>.
 
 =back
 
-=item B<new_from_string($text)>: returns I<Mail::SPF::Mod::Exp>; throws
-I<Mail::SPF::ENothingToParse>, I<Mail::SPF::EInvalidMod>
+=item B<new_from_string($text, %options)>: returns I<Mail::SPF::Mod::Exp>;
+throws I<Mail::SPF::ENothingToParse>, I<Mail::SPF::EInvalidMod>
 
-Creates a new SPF record C<exp> modifier object by parsing the given string.
+Creates a new SPF record C<exp> modifier object by parsing the string and
+any options given.
 
 =back
 
@@ -79,6 +82,10 @@ Returns B<'exp'>.
 
 Returns a regular expression that matches a modifier name of B<'exp'>.
 
+=item B<precedence>: returns I<real>
+
+Returns a precedence value of B<0.2>.  See L<Mail::SPF::Mod/precedence>.
+
 =back
 
 =head2 Instance methods
@@ -117,38 +124,39 @@ __PACKAGE__->make_accessor('domain_spec', TRUE);
 
 =item B<process($server, $request, $result)>
 
-If the given SPF result is a C<fail> result, retrieves an explanation string
-from the modifier's target domain and attaches it to the SPF result.  If an
-error occurs during the retrieval of the explanation string, does nothing, as
-if the modifier was not present.  See RFC 4408, 6.2, for details.
+If the given SPF result is a C<fail> result, retrieves the authority domain's
+explanation string from the modifier's target domain and attaches it to the SPF
+result.  If an error occurs during the retrieval of the explanation string,
+does nothing, as if the modifier was not present.  See RFC 4408, 6.2, for
+details.
 
 =cut
 
 sub process {
     my ($self, $server, $request, $result) = @_;
-    
+
     try {
         my $exp_domain = $self->{domain_spec}->new(server => $server, request => $request);
         my $txt_packet = $server->dns_lookup($exp_domain, 'TXT');
         my @txt_rrs = grep($_->type eq 'TXT', $txt_packet->answer);
         @txt_rrs > 0
-            or throw Mail::SPF::Result::PermError($request,
-                "No explanation string available at domain '$exp_domain'");  # RFC 4408, 6.2/4
+            or $server->throw_result('permerror', $request,
+                "No authority explanation string available at domain '$exp_domain'");  # RFC 4408, 6.2/4
         @txt_rrs == 1
-            or throw Mail::SPF::Result::PermError($request,
-                "Redundant explanation strings found at domain '$exp_domain'");  # RFC 4408, 6.2/4
+            or $server->throw_result('permerror', $request,
+                "Redundant authority explanation strings found at domain '$exp_domain'");  # RFC 4408, 6.2/4
         my $explanation = Mail::SPF::MacroString->new(
             text            => join('', $txt_rrs[0]->char_str_list),
             server          => $server,
             request         => $request,
             is_explanation  => TRUE
         );
-        $request->state('explanation', $explanation);
+        $request->state('authority_explanation', $explanation);
     }
     # Ignore DNS and other errors:
     catch Mail::SPF::EDNSError with {}
     catch Mail::SPF::Result::Error with {};
-    
+
     return;
 }
 
@@ -160,7 +168,7 @@ See L<Mail::SPF::Mod> for other supported instance methods.
 
 L<Mail::SPF>, L<Mail::SPF::Mod>, L<Mail::SPF::Term>, L<Mail::SPF::Record>
 
-L<RFC 4408|http://www.ietf.org/rfc/rfc4408.txt>
+L<http://tools.ietf.org/html/rfc4408>
 
 For availability, support, and license information, see the README file
 included with Mail::SPF.
