@@ -2,9 +2,9 @@
 # Mail::SPF::Mod::Redirect
 # SPF record "redirect" modifier class.
 #
-# (C) 2005-2006 Julian Mehnle <julian@mehnle.net>
+# (C) 2005-2012 Julian Mehnle <julian@mehnle.net>
 #     2005      Shevek <cpan@anarres.org>
-# $Id: Redirect.pm 30 2006-11-27 19:55:10Z Julian Mehnle $
+# $Id: Redirect.pm 57 2012-01-30 08:15:31Z julian $
 #
 ##############################################################################
 
@@ -28,6 +28,8 @@ use constant FALSE  => not TRUE;
 use constant name           => 'redirect';
 use constant name_pattern   => qr/${\name}/i;
 
+use constant precedence     => 0.8;
+
 =head1 DESCRIPTION
 
 An object of class B<Mail::SPF::Mod::Redirect> represents an SPF record
@@ -54,11 +56,11 @@ See L<Mail::SPF::Mod/new>.
 
 =back
 
-=item B<new_from_string($text)>: returns I<Mail::SPF::Mod::Redirect>; throws
-I<Mail::SPF::ENothingToParse>, I<Mail::SPF::EInvalidMod>
+=item B<new_from_string($text, %options)>: returns I<Mail::SPF::Mod::Redirect>;
+throws I<Mail::SPF::ENothingToParse>, I<Mail::SPF::EInvalidMod>
 
-Creates a new SPF record C<redirect> modifier object by parsing the given
-string.
+Creates a new SPF record C<redirect> modifier object by parsing the string and
+any options given.
 
 =back
 
@@ -76,6 +78,10 @@ Returns B<'redirect'>.
 
 Returns a regular expression that matches a modifier name of B<'redirect'>.
 
+=item B<precedence>: returns I<real>
+
+Returns a precedence value of B<0.8>.  See L<Mail::SPF::Mod/precedence>.
+
 =back
 
 =head2 Instance methods
@@ -119,36 +125,33 @@ performs a recursive SPF check using the given SPF server and request objects
 and substituting the modifier's target domain name for the request's authority
 domain.  The result of the recursive SPF check is then thrown as the result of
 the current record's evaluation.  However, if the target domain has no
-acceptable SPF record, a "permerror" result is thrown.  See RFC 4408, 6.1, for
+acceptable SPF record, a C<permerror> result is thrown.  See RFC 4408, 6.1, for
 details.
 
 =cut
 
 sub process {
     my ($self, $server, $request, $result) = @_;
-    
+
     $server->count_dns_interactive_term($request);
-    
+
     # Only perform redirection if no mechanism matched (RFC 4408, 6.1/1):
     $result->isa('Mail::SPF::Result::NeutralByDefault')
         or return;
-    
+
     # Create sub-request with mutated authority domain:
     my $authority_domain = $self->{domain_spec}->new(server => $server, request => $request);
     my $sub_request = $request->new_sub_request(authority_domain => $authority_domain);
-    
+
     # Process sub-request:
     $result = $server->process($sub_request);
-    
+
     # Translate result of sub-request (RFC 4408, 6.1/4):
-    throw Mail::SPF::Result::PermError($server, $request,
+    $server->throw_result('permerror', $request,
         "Redirect domain '$authority_domain' has no applicable sender policy")
         if $result->isa('Mail::SPF::Result::None');
-    
+
     # Propagate any other results as-is:
-    #$request->state('authority_explanation') = $sub_request->state('authority_explanation');
-    #    # Propagate authority result explanation from sub-request.
-    #    # FIXME Needed?  Seems not!  See TODO file.
     $result->throw();
 }
 
@@ -160,7 +163,7 @@ See L<Mail::SPF::Mod> for other supported instance methods.
 
 L<Mail::SPF>, L<Mail::SPF::Mod>, L<Mail::SPF::Term>, L<Mail::SPF::Record>
 
-L<http://www.ietf.org/rfc/rfc4408.txt>
+L<http://tools.ietf.org/html/rfc4408>
 
 For availability, support, and license information, see the README file
 included with Mail::SPF.
